@@ -4,58 +4,56 @@ import logging
 
 import voluptuous as vol
 
-import hatasmota.config_validation as cv
-from hatasmota.binary_sensor import (
-    TasmotaBinarySensor,
-    TasmotaBinarySensorConfig,
-    TasmotaSwitchTriggerConfig,
-    TasmotaSwitchTrigger,
-)
-from hatasmota.button import TasmotaButtonTriggerConfig, TasmotaButtonTrigger
-from hatasmota.const import (
+from . import config_validation as cv
+from .button import TasmotaButtonTrigger, TasmotaButtonTriggerConfig
+from .const import (
     CONF_BUTTON,
     CONF_DEVICENAME,
+    CONF_FRIENDLYNAME,
     CONF_FULLTOPIC,
     CONF_HOSTNAME,
     CONF_IP,
-    CONF_MAC,
     CONF_LIGHT_SUBTYPE,
     CONF_LINK_RGB_CT,
-    CONF_FRIENDLYNAME,
+    CONF_MAC,
     CONF_MANUFACTURER,
+    CONF_MODEL,
     CONF_NAME,
     CONF_OFFLINE,
     CONF_ONLINE,
     CONF_OPTIONS,
     CONF_PREFIX,
+    CONF_RELAY,
     CONF_SENSOR,
     CONF_STATE,
-    CONF_RELAY,
+    CONF_SW_VERSION,
+    CONF_SWITCH,
     CONF_TOPIC,
     CONF_TUYA,
     CONF_VERSION,
-    CONF_MODEL,
-    CONF_SW_VERSION,
-    CONF_SWITCH,
-    OPTION_BUTTON_SWAP,
     OPTION_BUTTON_SINGLE,
+    OPTION_BUTTON_SWAP,
     OPTION_DECIMAL_TEXT,
-    OPTION_NOT_POWER_LINKED,
     OPTION_HASS_LIGHT,
-    OPTION_PWM_MULTI_CHANNELS,
     OPTION_MQTT_BUTTONS,
+    OPTION_NOT_POWER_LINKED,
+    OPTION_PWM_MULTI_CHANNELS,
     OPTION_REDUCED_CT_RANGE,
     OPTION_SHUTTER_MODE,
     RL_LIGHT,
     RL_RELAY,
 )
-from hatasmota.light import TasmotaLight, TasmotaLightConfig
-from hatasmota.sensor import TasmotaSensor, get_sensor_entities
-from hatasmota.switch import TasmotaRelay, TasmotaRelayConfig
-from hatasmota.utils import (
-    discovery_topic_is_device_config,
-    discovery_topic_get_mac,
+from .light import TasmotaLight, TasmotaLightConfig
+from .relay import TasmotaRelay, TasmotaRelayConfig
+from .sensor import TasmotaSensor, get_sensor_entities
+from .status_sensor import TasmotaStatusSensor, TasmotaStatusSensorConfig
+from .switch import (
+    TasmotaSwitch,
+    TasmotaSwitchConfig,
+    TasmotaSwitchTrigger,
+    TasmotaSwitchTriggerConfig,
 )
+from .utils import discovery_topic_get_mac, discovery_topic_is_device_config
 
 TASMOTA_OPTIONS_SCHEMA = vol.Schema(
     {
@@ -247,7 +245,7 @@ def get_binary_sensor_entities(discovery_msg):
         entity = None
         discovery_hash = (discovery_msg[CONF_MAC], "binary_sensor", "switch", idx)
         if value:
-            entity = TasmotaBinarySensorConfig.from_discovery_message(
+            entity = TasmotaSwitchConfig.from_discovery_message(
                 discovery_msg, idx, "binary_sensor"
             )
         entities.append((entity, discovery_hash))
@@ -295,12 +293,27 @@ def get_light_entities(discovery_msg):
     return light_entities
 
 
+def get_status_sensor_entities(discovery_msg):
+    """Generate light configuration."""
+    status_sensor_entities = []
+
+    discovery_hash = (discovery_msg[CONF_MAC], "status_sensor", "status_sensor", 0)
+    entity = TasmotaStatusSensorConfig.from_discovery_message(
+        discovery_msg, "status_sensor"
+    )
+    status_sensor_entities.append((entity, discovery_hash))
+
+    return status_sensor_entities
+
+
 def get_entities_for_platform(discovery_msg, platform):
     """Generate configuration for the given platform."""
     if platform == "binary_sensor":
         return get_binary_sensor_entities(discovery_msg)
     if platform == "light":
         return get_light_entities(discovery_msg)
+    if platform == "sensor":
+        return get_status_sensor_entities(discovery_msg)
     if platform == "switch":
         return get_switch_entities(discovery_msg)
     return []
@@ -316,11 +329,13 @@ def get_entity(config, mqtt_client):
     """Create entity for the given platform."""
     platform = config.platform
     if platform == "binary_sensor":
-        return TasmotaBinarySensor(config=config, mqtt_client=mqtt_client)
+        return TasmotaSwitch(config=config, mqtt_client=mqtt_client)
     if platform == "light":
         return TasmotaLight(config=config, mqtt_client=mqtt_client)
     if platform == "sensor":
         return TasmotaSensor(config=config, mqtt_client=mqtt_client)
+    if platform == "status_sensor":
+        return TasmotaStatusSensor(config=config, mqtt_client=mqtt_client)
     if platform == "switch":
         return TasmotaRelay(config=config, mqtt_client=mqtt_client)
     return None
