@@ -37,12 +37,14 @@ from .const import (
     SENSOR_PRESSUREATSEALEVEL,
     SENSOR_PROXIMITY,
     SENSOR_REACTIVE_POWERUSAGE,
+    SENSOR_SPEED,
     SENSOR_TEMPERATURE,
     SENSOR_TODAY,
     SENSOR_TOTAL,
     SENSOR_TOTAL_START_TIME,
     SENSOR_TVOC,
     SENSOR_UNIT_PRESSURE,
+    SENSOR_UNIT_SPEED,
     SENSOR_UNIT_TEMPERATURE,
     SENSOR_VOLTAGE,
     SENSOR_WEIGHT,
@@ -147,10 +149,11 @@ SENSOR_UNIT_MAP = {
 }
 
 SENSOR_DYNAMIC_UNIT_MAP = {
-    SENSOR_TEMPERATURE: SENSOR_UNIT_TEMPERATURE,
     SENSOR_DEWPOINT: SENSOR_UNIT_TEMPERATURE,
     SENSOR_PRESSURE: SENSOR_UNIT_PRESSURE,
     SENSOR_PRESSUREATSEALEVEL: SENSOR_UNIT_PRESSURE,
+    SENSOR_SPEED: SENSOR_UNIT_SPEED,
+    SENSOR_TEMPERATURE: SENSOR_UNIT_TEMPERATURE,
 }
 
 _LOGGER = logging.getLogger(__name__)
@@ -169,11 +172,10 @@ class TasmotaSensorConfig(TasmotaAvailabilityConfig, TasmotaEntityConfig):
 
     @classmethod
     def from_discovery_message(
-        cls, device_config, sensor_config, platform, sensor_name, value_path
+        cls, device_config, sensor_config, platform, sensor_name, value_path, quantity
     ):
         """Instantiate from discovery message."""
-        quantity = value_path[-1]
-        unit = SENSOR_UNIT_MAP.get(quantity)
+        unit = SENSOR_UNIT_MAP.get(quantity, " ")
         if quantity in SENSOR_DYNAMIC_UNIT_MAP:
             unit = sensor_config[CONF_SENSOR].get(SENSOR_DYNAMIC_UNIT_MAP[quantity])
 
@@ -198,7 +200,7 @@ class TasmotaSensorConfig(TasmotaAvailabilityConfig, TasmotaEntityConfig):
     @property
     def unique_id(self):
         """Return unique_id."""
-        sensor_id = "_".join(self.value_path)
+        sensor_id = "_".join([str(i) for i in self.value_path])
         return f"{self.mac}_{self.platform}_{self.endpoint}_{sensor_id}"
 
 
@@ -293,6 +295,27 @@ class TasmotaSensor(TasmotaAvailability, TasmotaEntity):
 #   },
 #   "SpeedUnit":"km/h"
 # }
+def _get_sensor_entity(
+    sensor_discovery_message, device_discovery_msg, sensorpath, quantity
+):
+    sensorname = " ".join([str(i) for i in sensorpath])
+    discovery_hash = (
+        device_discovery_msg[CONF_MAC],
+        "sensor",
+        "sensor",
+        sensorname,
+    )
+    sensor_config = TasmotaSensorConfig.from_discovery_message(
+        device_discovery_msg,
+        sensor_discovery_message,
+        "sensor",
+        sensorname,
+        sensorpath,
+        quantity,
+    )
+    return (sensor_config, discovery_hash)
+
+
 def get_sensor_entities(sensor_discovery_message, device_discovery_msg):
     """Generate sensor configuration."""
     sensor_configs = []
@@ -303,28 +326,42 @@ def get_sensor_entities(sensor_discovery_message, device_discovery_msg):
         for subsensorkey, subsensor in sensor.items():
             subsensorpath = list(sensorpath)
             subsensorpath.append(subsensorkey)
+            quantity = subsensorkey
             if isinstance(subsensor, dict):
                 # Nested sensor
-                pass
+                for subsubsensorkey in subsensor.keys():
+                    subsubsensorpath = list(subsensorpath)
+                    subsubsensorpath.append(subsubsensorkey)
+                    sensor_configs.append(
+                        _get_sensor_entity(
+                            sensor_discovery_message,
+                            device_discovery_msg,
+                            subsubsensorpath,
+                            quantity,
+                        )
+                    )
             elif isinstance(subsensor, list):
                 # Array sensor
-                pass
+                for (idx, _) in enumerate(subsensor):
+                    subsubsensorpath = list(subsensorpath)
+                    subsubsensorpath.append(idx)
+                    sensor_configs.append(
+                        _get_sensor_entity(
+                            sensor_discovery_message,
+                            device_discovery_msg,
+                            subsubsensorpath,
+                            quantity,
+                        )
+                    )
             else:
-                # Quantity
-                sensorname = " ".join(subsensorpath)
-                discovery_hash = (
-                    device_discovery_msg[CONF_MAC],
-                    "sensor",
-                    "sensor",
-                    sensorname,
+                # Simple sensor
+                sensor_configs.append(
+                    _get_sensor_entity(
+                        sensor_discovery_message,
+                        device_discovery_msg,
+                        subsensorpath,
+                        quantity,
+                    )
                 )
-                sensor_config = TasmotaSensorConfig.from_discovery_message(
-                    device_discovery_msg,
-                    sensor_discovery_message,
-                    "sensor",
-                    sensorname,
-                    subsensorpath,
-                )
-                sensor_configs.append((sensor_config, discovery_hash))
 
     return sensor_configs
