@@ -1,9 +1,10 @@
 """Tasmota utility functions."""
-from functools import reduce
+import collections
 import json
 import logging
 import operator
 import re
+from functools import reduce
 
 from .const import (
     CONF_DEVICENAME,
@@ -11,20 +12,20 @@ from .const import (
     CONF_FULLTOPIC,
     CONF_HOSTNAME,
     CONF_MAC,
+    CONF_OFFLINE,
+    CONF_ONLINE,
     CONF_PREFIX,
     CONF_STATE,
     CONF_TOPIC,
     PREFIX_CMND,
     PREFIX_STAT,
     PREFIX_TELE,
-    STATE_OFF,
-    STATE_ON,
-    CONF_ONLINE,
-    CONF_OFFLINE,
     RSLT_ACTION,
     RSLT_POWER,
     RSLT_STATE,
     RSLT_TRIG,
+    STATE_OFF,
+    STATE_ON,
 )
 
 _LOGGER = logging.getLogger(__name__)
@@ -161,7 +162,8 @@ def get_value(status, key, idx=None, idx_optional=False):
 def get_value_by_path(status, path):
     """Get status from JSON formatted status or result by path."""
     try:
-        status = json.loads(status)
+        if not isinstance(status, collections.Mapping):
+            status = json.loads(status)
         return get_by_path(status, path)
     except (json.decoder.JSONDecodeError, KeyError):
         return None
